<template>
  <div class="TimeSliderItem">
    <div class="week">{{ weekArr[day] }}</div>
    <el-slider
      v-model="minuteRange"
      range
      :max="1439"
      :format-tooltip="transToTime"
      height="40"
      :marks="marks"
      :disabled="!edit"
      @change="sliderChange"
    >
    </el-slider>
    <div class="label">开始</div>
    <el-time-picker
      v-model="timeRange[0]"
      placeholder=""
      align="center"
      format="HH:mm"
      value-format="HH:mm"
      @change="pickChange"
      :disabled="!edit"
      popper-class="timePick"
    >
    </el-time-picker>
    <div class="label">结束</div>
    <el-time-picker
      v-model="timeRange[1]"
      placeholder=""
      align="center"
      format="HH:mm"
      value-format="HH:mm"
      @change="pickChange"
      :disabled="!edit"
      popper-class="timePick"
    >
    </el-time-picker>
  </div>
</template>

<script>
export default {
  props: {
    Timedata: {},
    day: {},
    edit: {},
  },
  model: {
    prop: "Timedata",
    event: "updateTime",
  },

  created() {
    this.initTime();
  },
  data() {
    return {
      minuteRange: [0, 0],
      timeRange: ["00:00", "23:59"],
      weekArr: [
        "星期一",
        "星期二",
        "星期三",
        "星期四",
        "星期五",
        "星期六",
        "星期日",
      ],
      marks: {
        0: "0",
        360: "6",
        720: "12",
        1080: "18",
        1439: "24",
      },
    };
  },
  methods: {
    initTime() {
      if (this.Timedata[0].end === "24:00") {
        this.Timedata[0].end = "23:59";
      }

      let start = this.transToMiunte(this.Timedata[0].start);
      let end = this.transToMiunte(this.Timedata[0].end);

      this.timeRange = [this.Timedata[0].start, this.Timedata[0].end];
      this.minuteRange = [start, end];
    },
    //分钟数转时间
    transToTime(value) {
      let minute = parseInt(value % 60);
      let hour = parseInt(value / 60);

      if (minute < 10) {
        minute = "0" + minute;
      }
      if (hour < 10) {
        hour = "0" + hour;
      }
      let result = hour + ":" + minute;
      return result;
    },
    //时间转分钟数
    transToMiunte(arr) {
      let hour = +arr.split(":")[0];
      let minute = +arr.split(":")[1];
      return hour * 60 + minute;
    },
    //滑动组件回调
    sliderChange(value) {
      let start = this.transToTime(value[0]);
      let end = this.transToTime(value[1]);
      this.timeRange = [start, end];

      this.$emit("updateTime", [
        {
          start: this.timeRange[0],
          end: this.timeRange[1],
        },
      ]);
    },
    pickChange() {
      let start = this.transToMiunte(this.timeRange[0]);
      let end = this.transToMiunte(this.timeRange[1]);
      this.minuteRange = [start, end];

      this.$emit("updateTime", [
        {
          start: this.timeRange[0],
          end: this.timeRange[1],
        },
      ]);
    },
  },
};
</script>

<style lang="scss" scoped>
.TimeSliderItem {
  margin-top: 44px;
  box-sizing: border-box;
  display: flex;
  padding: 0 20px;
  font-size: 14px;

  .week {
    margin-right: 10px;
  }

  .el-slider ::v-deep {
    flex: 1;

    .el-tooltip {
      visibility: hidden;
      margin-top: 14px;
    }

    .el-slider__stop {
      display: none;
    }

    .el-slider__marks-text {
      margin-top: 21px;
      font-size: 12px;
    }

    .el-slider__runway {
      margin: 0 0;
      height: 20px;
      border-radius: 0;
      background: #e9ebee;

      .el-slider__bar {
        height: 100%;
        background-color: #0064ff;
        border-radius: 0;
      }
    }
  }

  .label {
    margin-left: 14px;
    margin-right: 6px;
    color: #666;
  }

  .el-date-editor ::v-deep {
    box-sizing: border-box;
    margin-top: -5px;
    width: 67px;
    height: 32px;

    .el-input__icon,
    .el-input__suffix {
      display: none;
    }

    input {
      box-sizing: border-box;
      height: 32px;
      padding: 6px 10px;
      font-size: 14px;
      color: #3d3d3d;
      border: 1px solid #c0c5cc;
    }
  }
}
</style>

<style lang="scss"  >
.timePick {
  margin-top: 0;
  width: 120px;

  .popper__arrow {
    display: none;
  }

  .el-time-panel__content::after,
  .el-time-panel__content::before {
    border: none;
  }

  .el-time-spinner__item.active {
    color: #0064ff;
  }

  .el-time-panel__footer {
    .cancel {
      line-height: 18px;
      color: #0064ff;
      border: 1px solid #0064ff;
    }

    .confirm {
      margin-right: 14px;
      color: #fff;
      line-height: 18px;
      background-color: #0064ff;
      border: 1px solid #0064ff;
    }
  }
}
</style>